@@ -5,6 +5,7 @@
  * guppi-pricebars-item.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>
  *
@@ -42,12 +43,10 @@ struct _GuppiPricebarsItem {
   gint buf_size;
 
   double pixels_per_day;
+  gint horiz_tick_size;
 
-  double *t_op_buf;
-  double *t_hi_buf;
-  double *t_lo_buf;
-  double *t_cl_buf;
-
+  gint Nbuf;
+  double *t_buf;
   double *op_buf;
   double *hi_buf;
   double *lo_buf;
@@ -73,4 +72,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PRICEBARS_ITEM_H */
 
-/* $Id: guppi-pricebars-item.h,v 1.3 2001/01/16 23:36:03 trow Exp $ */
+/* $Id: guppi-pricebars-item.h,v 1.5 2001/11/16 16:58:40 trow Exp $ */
