@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-markers.h,v 1.11 2001/10/15 20:58:41 trow Exp $ */
+/* $Id: guppi-axis-markers.h,v 1.13 2002/01/20 06:45:07 jody Exp $ */
 
 /*
  * guppi-axis-markers.h
@@ -32,7 +32,7 @@
 /* #include <gnome.h> */
 #include <libgnomeprint/gnome-font.h>
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -53,7 +53,8 @@ enum {
   GUPPI_AXIS_SCALAR_LOG10=3,
   GUPPI_AXIS_PERCENTAGE=4,
   GUPPI_AXIS_DATE=5,
-  GUPPI_AXIS_LAST=6
+  GUPPI_AXIS_XL_DATE=6, /* Accept the butchered MS Excel (tm) date serials */
+  GUPPI_AXIS_LAST=7
 };
 
 typedef struct _GuppiTick GuppiTick;
@@ -140,7 +141,8 @@ void guppi_axis_markers_populate_scalar_log (GuppiAxisMarkers *,
 					     gint goal, double base);
 
 void guppi_axis_markers_populate_dates (GuppiAxisMarkers *,
-					GDate *min, GDate *max);
+					GDate *min, GDate *max,
+					gboolean do_excel_adjustment);
 
 void guppi_axis_markers_populate_generic (GuppiAxisMarkers *,
 					  gint type,
@@ -158,4 +160,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_AXIS_MARKERS_H */
 
-/* $Id: guppi-axis-markers.h,v 1.11 2001/10/15 20:58:41 trow Exp $ */
+/* $Id: guppi-axis-markers.h,v 1.13 2002/01/20 06:45:07 jody Exp $ */
