@@ -1,6 +1,6 @@
 /* This is -*- C -*- */
 /* vim: set sw=2: */
-/* $Id: guppi-regression-polynomial.h,v 1.2 2001/05/04 06:11:41 trow Exp $ */
+/* $Id: guppi-regression-polynomial.h,v 1.4 2001/11/19 05:40:47 trow Exp $ */
 
 /*
  * guppi-regression-polynomial.h
@@ -29,8 +29,8 @@
 #define _INC_GUPPI_REGRESSION_POLYNOMIAL_H
 
 #include <gnome.h>
-#include <guppi-defs.h>
-#include <guppi-polynomial.h>
+#include  "guppi-defs.h"
+#include  "guppi-polynomial.h"
 #include "guppi-regression2d.h"
 
 
@@ -56,9 +56,6 @@ struct _GuppiRegressionPolynomialClass {
 #define GUPPI_IS_REGRESSION_POLYNOMIAL0(obj) (((obj) == NULL) || (GUPPI_IS_REGRESSION_POLYNOMIAL(obj)))
 #define GUPPI_IS_REGRESSION_POLYNOMIAL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_REGRESSION_POLYNOMIAL))
 
-#define g_return_unless_is_guppi_regression_polynomial(x) (g_return_if_fail((x)&&GUPPI_IS_REGRESSION_POLYNOMIAL((x))))
-#define g_return_val_unless_is_guppi_regression_polynomial(x,y) (g_return_val_if_fail((x)&&GUPPI_IS_REGRESSION_POLYNOMIAL((x)),(y)))
-
 GtkType guppi_regression_polynomial_get_type (void);
 
 GuppiRegression2D *guppi_regression_polynomial_new (void);
@@ -74,4 +71,4 @@ END_GUPPI_DECLS;
 
 #endif /* _INC_GUPPI_REGRESSION_POLYNOMIAL_H */
 
-/* $Id: guppi-regression-polynomial.h,v 1.2 2001/05/04 06:11:41 trow Exp $ */
+/* $Id: guppi-regression-polynomial.h,v 1.4 2001/11/19 05:40:47 trow Exp $ */
