@@ -1,6 +1,6 @@
 /* This is -*- C -*- */
 /* vim: set sw=2: */
-/* $Id: gnan.c,v 1.4 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: gnan.c,v 1.9 2002/01/14 05:01:23 trow Exp $ */
 
 /*
  * gnan.c
@@ -26,10 +26,12 @@
  */
 
 #include <config.h>
+#include "gnan.h"
+
+#include <string.h>
 #include <signal.h>
 #include <glib.h>
 #include "guppi-debug.h"
-#include "gnan.h"
 
 
 union ieee754_big_endian_double {
@@ -84,8 +86,9 @@ static const guint alpha_nan_bits_B[8] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0xff
 };
 
+const double G_NAN;
+
 #ifndef NAN
-const double NAN;
 static gboolean fake_isnan = FALSE;
 #endif
 
@@ -111,12 +114,31 @@ g_isnan (double x)
 #endif
 }
 
+gboolean
+g_isinf (double x)
+{
+  /* FIXME: This needs to be made portable. */
+  return isinf (x);
+}
+
+gboolean
+g_finite (double x)
+{
+  /* FIXME: This needs to be made portable. */
+  return finite (x);
+}
 
 void
 gnan_init (void)
 {
 #ifdef NAN
+
+  double d = NAN;
+
+  /* If we have NAN, we just use it. */
   g_assert (isnan (NAN));
+  memcpy ((double *)&G_NAN, &d, sizeof (double));
+
 #else
   union ieee754_big_endian_double be;
   union ieee754_little_endian_double le;
@@ -139,8 +161,8 @@ gnan_init (void)
     be.ieee.man1 = 1;
     be.ieee.exp = 2047;
 
-    memcpy ((double *)&NAN, &be.d, sizeof (double));
-    if (isnan (NAN)) return;
+    memcpy ((double *)&G_NAN, &be.d, sizeof (double));
+    if (isnan (G_NAN)) return;
   }
 
   le.d = NUMBER;
@@ -155,8 +177,8 @@ gnan_init (void)
     le.ieee.man1 = 1;
     le.ieee.exp = 2047;
 
-    memcpy ((double *)&NAN, &le.d, sizeof (double));
-    if (isnan (NAN)) return;
+    memcpy ((double *)&G_NAN, &le.d, sizeof (double));
+    if (isnan (G_NAN)) return;
   }
 
   me.d = NUMBER;
@@ -171,10 +193,20 @@ gnan_init (void)
     me.ieee.man1 = 1;
     me.ieee.exp = 2047;
 
-    memcpy ((double *)&NAN, &me.d, sizeof (double));
-    if (isnan (NAN)) return;
+    memcpy ((double *)&G_NAN, &me.d, sizeof (double));
+    if (isnan (G_NAN)) return;
   }
 
+  /* Morten Welinder tells me that "Some people here argue that the
+     specs guarantee a NaN to come out of this."  It is certainly
+     worth a try... */
+  {
+    double a = -HUGE_VAL;
+    double b = 0;
+    *(double *)&G_NAN = a * b;
+    if (isnan (G_NAN)) return;
+  }
+  
   /* This is abusive, but I need a quick and dirty way of
      handling Alpha FP right away... */
   d = ALPHA_TEST_VALUE;
@@ -188,10 +220,10 @@ gnan_init (void)
     }
 
     if (ok) {
-      memcpy ((gpointer)&NAN, alpha_nan_bits_A, 8);
-      if (isnan (NAN)) return;
-      memcpy ((gpointer)&NAN, alpha_nan_bits_B, 8);
-      if (isnan (NAN)) return;
+      memcpy ((gpointer)&G_NAN, alpha_nan_bits_A, 8);
+      if (isnan (G_NAN)) return;
+      memcpy ((gpointer)&G_NAN, alpha_nan_bits_B, 8);
+      if (isnan (G_NAN)) return;
     }
   }
 
@@ -206,7 +238,7 @@ gnan_init (void)
     sigaction (SIGFPE, &old_fpe, NULL);
     
     if (isnan (d)) {
-      memcpy ((gpointer)&NAN, &d, sizeof (double));
+      memcpy ((gpointer)&G_NAN, &d, sizeof (double));
       return;
     }
   }
@@ -216,9 +248,9 @@ gnan_init (void)
 
   d = FAKE_NAN;
   fake_isnan = TRUE;
-  memcpy ((gpointer)&NAN, &d, sizeof (double));
+  memcpy ((gpointer)&G_NAN, &d, sizeof (double));
 
-  g_assert (g_isnan (NAN));
+  g_assert (g_isnan (G_NAN));
   guppi_msg ("Using awful FAKE_NAN hack.");
   
 #endif /* NAN */
@@ -226,4 +258,4 @@ gnan_init (void)
 
 
 
-/* $Id: gnan.c,v 1.4 2000/12/21 22:23:33 trow Exp $ */
+/* $Id: gnan.c,v 1.9 2002/01/14 05:01:23 trow Exp $ */
